from .events import Event


class IndicatorBroadcaster:
    """
    It can register indicators and also provide a way to notify them regarding changes in
      data. In the same way, provides a mean to return its own data.
    """

    def __init__(self, source):
        self._on_refresh_indicators = Event()
        self._source = source

    @property
    def on_refresh_indicators(self):
        """
        This event will be triggered on data change so the indicators can update.
        """

        return self._on_refresh_indicators

    @property
    def source(self):
        """
        The source this broadcaster ultimately get the data from.
        """

        return self._source

    def __getitem__(self, item):
        """
        Gets underlying data from this broadcaster.
        """

        raise NotImplementedError



from setuptools import setup

setup(
    name='mistra',
    version='0.0.11',
    packages=['mistra.core',
              'mistra.core.growing_arrays',
              'mistra.core.indicators',
              'mistra.core.indicators.mixins',
              'mistra.core.indicators.stats',
              'mistra.core.utils',
              'mistra.core.utils.mappers'],
    url='',
    license='MIT',
    author='luismasuelli',
    author_email='luisfmasuelli@gmail.com',
    description='MISTRA (Market InSights / TRading Algorithms) provides core support to market timelapses and indicators management',
    python_requires='>=3.3',
    install_requires=['numpy==1.17.4', 'requests==2.22.0', 'scipy==1.3.2']
)
